@@ -6,4 +6,4 @@ set -x
 mypy wgus
 flake8 wgus tests
 black wgus tests --check
-isort wgus tests scripts --check-only
+isort wgus tests --check-only
