@@ -8,9 +8,8 @@ async def request(method: str, host: str, path: str, query: Dict[str, str]) -> s
     async with aiohttp.request(
         method, URL.build(scheme="https", host=host, path=path, query=query)
     ) as req:
-        data = await req.text()
         req.raise_for_status()
-        return data
+        return await req.text()
 
 
 async def get(host: str, path: str, query: Dict[str, str]) -> str:
